
// Replace this with the directory containing the do-files and data:
cd "mydirectory"

use parcel_data, clear


/*Sample restrictions (2000-2009, own WRLURI, nbr WRLURI)*/
drop if year_lt00 == 1
drop if pricepersflandgross == . 
keep if wrluri_parcel == 1 & wrluri_nbr == 1 & own_wrluri != .

/* For some reason, med_hh_inc was of the wrong magnitude. Scale it up */
replace own_med_hh_inc = 1000*own_med_hh_inc
replace nbr_med_hh_inc = 1000*nbr_med_hh_inc

/*Generate cross-border change variables*/
foreach var in edu_bs med_hh_inc {
	gen d_`var' = (own_`var' - nbr_`var') 
}

/*Calculate statistics*/

/*
local obs_2 = _N

/*Number of WRLURI municipalities*/
by own_fips_wrluri, sort: gen own_fips_wrluri_nvals = _n == 1 
count if own_fips_wrluri_nvals 
local muni_2 = r(N)

/*Number of WRLURI borders*/
by border_code, sort: gen border_code_nvals = _n == 1
count if border_code_nvals
local border_2 = r(N)
*/

**************************************************************************************************************
* All straight with WRLURI, corners = 500m
**************************************************************************************************************	

preserve
keep if straight_new_dis_noc500m == 1

/*Calculate statistics*/
local obs_3 = _N
foreach var of varlist pricepersflandgross land log_cbd_dist own_edu_bs own_med_hh_inc own_wrluri own_llla own_dri own_osi {
	sum `var'
	local mean_3_`var' = r(mean)
	local sd_3_`var' = r(sd)	
}
foreach var of varlist d_edu_bs d_med_hh_inc d_wrluri d_llla d_dri d_osi {
	replace `var' = abs(`var')
	sum `var'
	local mean_3_`var' = r(mean)
	local sd_3_`var' = r(sd)
}

/*Number of WRLURI municipalities*/
cap drop own_fips_wrluri_nvals
by own_fips_wrluri, sort: gen own_fips_wrluri_nvals = _n == 1 
count if own_fips_wrluri_nvals 
local muni_3 = r(N)

/*Number of WRLURI borders*/
cap drop border_code_nvals
by border_code, sort: gen border_code_nvals = _n == 1
count if border_code_nvals
local border_3 = r(N)

restore

**************************************************************************************************************
* All straight with WRLURI, corners = 1km
**************************************************************************************************************	

preserve
keep if straight_new_dis_noc1km == 1

/*Calculate statistics*/
local obs_4 = _N
foreach var of varlist pricepersflandgross land log_cbd_dist own_edu_bs own_med_hh_inc own_wrluri own_llla own_dri own_osi {
	sum `var'
	local mean_4_`var' = r(mean)
	local sd_4_`var' = r(sd)	
}
foreach var of varlist d_edu_bs d_med_hh_inc d_wrluri d_llla d_dri d_osi {
	replace `var' = abs(`var')
	sum `var'
	local mean_4_`var' = r(mean)
	local sd_4_`var' = r(sd)
}

/*Number of WRLURI municipalities*/
cap drop own_fips_wrluri_nvals
by own_fips_wrluri, sort: gen own_fips_wrluri_nvals = _n == 1 
count if own_fips_wrluri_nvals 
local muni_4 = r(N)

/*Number of WRLURI borders*/
cap drop border_code_nvals
by border_code, sort: gen border_code_nvals = _n == 1
count if border_code_nvals
local border_4 = r(N)

restore

**************************************************************************************************************
* All straight with WRLURI, corners = 1km, distance < 100m
**************************************************************************************************************	

preserve
keep if straight_new_dis_noc1km == 1

/*Restrict to parcels within 100m of a municipal border*/
global dist100 = 0.1
sort border_code nbr_dist
by border_code : egen min_dist_straight = min(nbr_dist) if straight_new_dis_noc1km == 1
gen border_straight = (min_dist_straight < ${dist100})
by border_code : egen border_straight100 = max(border_straight)
drop border_straight min_dist_straight
keep if (nbr_dist < ${dist100}) & (border_straight100 == 1)

/*Calculate statistics*/
local obs_5 = _N
foreach var of varlist pricepersflandgross land log_cbd_dist own_edu_bs own_med_hh_inc own_wrluri own_llla own_dri own_osi {
	sum `var'
	local mean_5_`var' = r(mean)
	local sd_5_`var' = r(sd)	
}
foreach var of varlist d_edu_bs d_med_hh_inc d_wrluri d_llla d_dri d_osi {
	replace `var' = abs(`var')
	sum `var'
	local mean_5_`var' = r(mean)
	local sd_5_`var' = r(sd)
}

/*Number of WRLURI municipalities*/
capture drop own_fips_wrluri_nvals
by own_fips_wrluri, sort: gen own_fips_wrluri_nvals = _n == 1 
count if own_fips_wrluri_nvals 
local muni_5 = r(N)

/*Number of WRLURI borders*/
capture drop border_code_nvals
by border_code, sort: gen border_code_nvals = _n == 1
count if border_code_nvals
local border_5 = r(N)

restore

**************************************************************************************************************
* All straight with WRLURI, corners = 1km, interior bin = 250-500m, boundary bin = 0-250m
**************************************************************************************************************	

preserve
keep if straight_new_dis_noc1km == 1
drop if missing(d_wrluri)

/*Restrict to parcels within interior and boundary bins*/
global bins "0.5 0.25 0.25"
global interior1 = real(word("${bins}", 1))
global interior2 = real(word("${bins}", 2))
global peripheral1 = real(word("${bins}", 3))
keep if ((nbr_dist < ${peripheral1}) | (nbr_dist < ${interior1} & nbr_dist > ${interior2}))

/*Calculate statistics*/
local obs_6 = _N
foreach var of varlist pricepersflandgross land log_cbd_dist own_edu_bs own_med_hh_inc own_wrluri own_llla own_dri own_osi {
	sum `var'
	local mean_6_`var' = r(mean)
	local sd_6_`var' = r(sd)	
}
foreach var of varlist d_edu_bs d_med_hh_inc d_wrluri d_llla d_dri d_osi {
	replace `var' = abs(`var')
	sum `var'
	local mean_6_`var' = r(mean)
	local sd_6_`var' = r(sd)
}

/*Number of WRLURI municipalities*/
cap drop own_fips_wrluri_nvals
by own_fips_wrluri, sort: gen own_fips_wrluri_nvals = _n == 1 
count if own_fips_wrluri_nvals 
local muni_6 = r(N)

/*Number of WRLURI borders*/
/*cap drop border_code_nvals
by border_code, sort: gen border_code_nvals = _n == 1
count if border_code_nvals
*/
cap drop muni_border_code_nvals
by muni_border_code, sort: gen muni_border_code_nvals = _n == 1
count if muni_border_code_nvals
local border_6 = r(N)
//export excel using summarystats_numborders_table6.xlsx if border_code_nvals, replace firstrow(variables)

restore

**************************************************************************************************************
* Build output table
**************************************************************************************************************	

/*Generate new variables*/
clear
gen var = ""
forvalues x = 1/6 {
	gen sample_`x' = . 
}
set obs 34

/*Fill in variable labels*/
local i = 2
foreach var in pricepersflandgross land log_cbd_dist own_edu_bs d_edu_bs own_med_hh_inc d_med_hh_inc own_wrluri d_wrluri own_llla d_llla own_dri d_dri own_osi d_osi {
	replace var = "`var'" in `i' 
	local i = `i' + 2
}
replace var = "obs" in 32
replace var = "muni" in 33
replace var = "border" in 34

/*Fill in table*/
local N = _N
forvalues col = 3/6 {
	foreach var in pricepersflandgross land log_cbd_dist own_edu_bs d_edu_bs own_med_hh_inc d_med_hh_inc own_wrluri d_wrluri own_llla d_llla own_dri d_dri own_osi d_osi {
		forvalues x = 1/`N' {
			if "`var'" == var[`x'] {
				local y = `x' + 1
				capture replace sample_`col' = `mean_`col'_`var'' in `x' 
				capture replace sample_`col' = `sd_`col'_`var'' in `y' 
			}
		}
	}
	foreach control in obs muni border {
		forvalues x = 1/`N' {
			if "`control'" == var[`x'] {
				capture replace sample_`col' = ``control'_`col'' in `x' 
			}
		}
	}
}

/*Convert variables to strings and round*/
forvalues x = 3/6 {
	tostring sample_`x', replace force format(%10.2f)
	forvalues y = 32/34 {
		replace sample_`x' = subinstr(sample_`x'[`y'], ".00", "", .) in `y'
	}
}

/*Add parentheses to standard errors*/
local N = _N
forvalues col = 3/6 {
	forvalues x = 3(2)31 {
		local sd = sample_`col'[`x']
		capture replace sample_`col' = "(" + "`sd'" + ")" in `x' 
	}
}

/*Add in column titles*/
replace var = "Variable" in 1

replace sample_3 = "All straight & WRLURI, 500m" in 1
replace sample_4 = "All straight & WRLURI, 1km" in 1
replace sample_5 = "Table 2, row 3" in 1
replace sample_6 = "Table 6, row 2" in 1

/*Replace missing values*/
//replace sample_1 = "" if sample_1 == "." | sample_1 == "(.)"
//replace sample_2 = "" if sample_2 == "." | sample_2 == "(.)"

export excel using table1_summary_statistics.xls, replace
